/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
import { AcaFolderRulesModule } from '@alfresco/aca-content/folder-rules';
export declare class RulesApi {
    private apiService;
    constructor();
    static initialize(userName: string, password?: string): Promise<RulesApi>;
    private callApi;
    createRule(nodeId: string, rule: Partial<Rule>, ruleSetId?: string): Promise<Rule>;
    createRandomRule(folderId: string, ruleName: string): Promise<Rule>;
    createRandomRuleWithMultipleConditions(folderId: string, ruleName: string, numOfConditions: number): Promise<Rule>;
    createRandomRuleWithMultipleActions(folderId: string, ruleName: string, numOfActions: number): Promise<Rule>;
    createRandomComplexRule(folderId: string, ruleName: string, numOfConditions: number, numOfActions: number, ruleDescription?: string): Promise<Rule>;
    createRuleWithRandomAspects(folderId: string, ruleName: string): Promise<Rule>;
    createRuleWithDestinationFolder(folderId: string, ruleName: string, actionType: 'move' | 'copy' | 'import', destinationFolderId: string): Promise<Rule>;
}
type RuleTrigger = 'inbound' | 'update' | 'outbound';
export interface Rule {
    id: string;
    name: string;
    description: string;
    isEnabled: boolean;
    isInheritable: boolean;
    isAsynchronous: boolean;
    errorScript: string;
    isShared: boolean;
    triggers: RuleTrigger[];
    conditions: AcaFolderRulesModule;
    actions: RuleAction[];
}
export interface RuleAction {
    actionDefinitionId: string;
    params?: {
        [key: string]: unknown;
    };
}
export declare class ActionTypes {
    key: string;
    value: RuleAction;
    static readonly ADDFEATURES: ActionTypes;
    static readonly CHECKIN: ActionTypes;
    static readonly SPECIALISETYPE: ActionTypes;
    static readonly SETPROPERTYVALUE: ActionTypes;
    static readonly actions: RuleAction[];
    constructor(key: string, value: RuleAction);
}
export declare class ConditionsTypes {
    key: string;
    value: AcaFolderRulesModule;
    static readonly MIMETYPE: ConditionsTypes;
    static readonly CMNAME: ConditionsTypes;
    static readonly SIZE: ConditionsTypes;
    static readonly TAG: ConditionsTypes;
    static readonly conditions: AcaFolderRulesModule[];
    constructor(key: string, value: AcaFolderRulesModule);
}
export {};
