/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
import { Locator, Page } from '@playwright/test';
import { BaseComponent } from '../base.component';
import { MatMenuComponent } from './mat-menu.component';
import { PaginationComponent } from '../pagination.component';
export declare class DataTableComponent extends BaseComponent {
    private static rootElement;
    contextMenuActions: MatMenuComponent;
    constructor(page: Page, rootElement?: string);
    pagination: PaginationComponent;
    body: Locator;
    getEmptyFolderLocator: Locator;
    getEmptyContentTitleLocator: Locator;
    getEmptyContentSubTitleLocator: Locator;
    getSelectedRow: Locator;
    sortedColumnHeader: Locator;
    columnHeaders: Locator;
    emptyList: Locator;
    emptyListTitle: Locator;
    emptyListSubtitle: Locator;
    emptySearchText: Locator;
    emptyListTest: Locator;
    paginationButton: Locator;
    paginationOptions: Locator;
    sitesVisibility: Locator;
    sitesName: Locator;
    sitesRole: Locator;
    lockOwner: Locator;
    uncheckedCheckbox: Locator;
    checkedCheckbox: Locator;
    highlightedText: string;
    searchFileName: string;
    searchFileDescription: string;
    searchFileContent: string;
    /** Locator for row (or rows) */
    getRowLocator: Locator;
    /** Locator to get "No results found" message */
    getNoResultsFoundMessage: Locator;
    /**
     * Method used in cases where we want to check that some record is visible in the datatable. It will consider whole row
     *
     * @returns reference to cell element which contains text.
     */
    getRowByName: (name: string | number) => Locator;
    /**
     * Method used in cases where we want to check that some record is visible in the datatable.
     * But we want to check it by column header title and value of this column.
     *
     * @returns reference to cell element which contains text.
     */
    getRowByColumnTitleAndItsCellValue: (columnTitle: string, cellValue: string | number) => Locator;
    /**
     * Method used in cases where we want to retrieve a row from the datatable based on its numerical order within the array.
     *
     * @returns reference to cell element which contains text.
     */
    getNthRow: (orderNum: number) => Locator;
    /**
     * Method used in cases where user have possibility to navigate "inside" the element (it's clickable and has link attribute).
     * Perform action .click() to navigate inside it
     *
     * @returns reference to cell element which contains link.
     */
    getCellLinkByName: (name: string) => Locator;
    /**
     * Method used in cases where we want to localize the element by [aria-label]
     *
     * @returns reference to cell element.
     */
    getByAriaLabelTitle: (title: string) => Locator;
    /**
     * Method used in cases where we want to get the button (hamburger menu) for row element
     *
     * @returns reference to menu placed in row localized by the name
     */
    getActionsButtonByName: (name: string) => Locator;
    /**
     * Method used in cases where we want to get the edit button and there is no hamburger menu
     *
     * @returns reference to edit button placed in row localized by the name
     */
    getEditButtonByName: (name: string) => Locator;
    /**
     * Method used in cases where we want to get the button and there is no hamburger menu
     *
     * @returns reference to button placed in row localized by the name
     */
    getButtonByNameForSpecificRow: (elementTitleInRow: string, buttonTitle: string) => Locator;
    /**
     * Method used in cases where you want to get some specific cell (by column name) for row which contains some name/title/etc.
     *
     * @returns reference to cell element
     */
    getCellByColumnNameAndRowItem: (item: string | number, columnName: string) => Locator;
    /**
     * Method used in cases where we want to get the checkbox for row element
     *
     * @returns reference to checkbox placed in row localized by the name
     */
    getCheckboxForElement: (item: string) => Locator;
    getColumnHeaderByTitleLocator: (headerTitle: string) => Locator;
    getSearchResultLinkByName: (name: string) => Locator;
    getColumnValuesByName: (name: string) => Locator;
    getColumnHeaderByName: (headerTitle: string) => Locator;
    sortBy(label: string, order: 'asc' | 'desc'): Promise<void>;
    /**
     * This method is used when we want to perform right mouse click on the dataTable row and perform some action
     *
     * @param name of the data table element with which we want to click
     * @param action provide which action you want to perform
     */
    performActionFromExpandableMenu(name: string | number, action: string): Promise<void>;
    /**
     * Click action from the expandable kebab menu for the element in datatable
     *
     * @param name title of the record you would like to proceed
     * @param action provide button title for the action
     * @param subAction if the action is in sub menu, then provide it here
     */
    performActionForElement(name: string, action: string, subAction?: string): Promise<void>;
    /**
     * This method is used when we want to perform double click on the dataTable row to open a file or folder
     *
     * @param name of the data table element with which we want to double click
     */
    performClickFolderOrFileToOpen(name: string): Promise<void>;
    isItemPresent(name: string): Promise<boolean>;
    getActionLocatorFromExpandableMenu(name: string | number, action: string): Promise<Locator>;
    performActionInExpandableMenu(name: string | number, action: string): Promise<void>;
    goThroughPagesLookingForRowWithName(name: string | number): Promise<void>;
    selectItems(...names: string[]): Promise<void>;
    isRowSelected(itemName: string): Promise<boolean>;
    getColumnHeaders(): Promise<Array<string>>;
    getSortedColumnHeaderText(): Promise<string>;
    private getItemLocationEl;
    getItemLocationText(name: string): Promise<string>;
    getItemLocationTooltip(name: string): Promise<string>;
    clickItemLocation(name: string): Promise<void>;
    getSortingOrder(): Promise<string>;
    getRowAllInnerTexts(name: string): Promise<string>;
    getFirstElementDetail(name: string): Promise<string>;
    isEmpty(): Promise<boolean>;
    getEmptyStateTitle(): Promise<string>;
    getEmptyStateSubtitle(): Promise<string>;
    getEmptyListText(): Promise<string>;
    getRowsCount(): Promise<number>;
    rightClickOnItem(itemName: string): Promise<void>;
    setPaginationTo50(): Promise<void>;
    /**
     * Method used to create objects from names and visibility of sites from datatable
     *
     * @returns an object with sites' names and their corresponding visibility values
     */
    getSitesNameAndVisibility(): Promise<{
        [siteName: string]: string;
    }>;
    /**
     * Method used to create objects from names and roles of sites from datatable
     *
     * @returns an object with sites' names and their corresponding role values
     */
    getSitesNameAndRole(): Promise<{
        [siteName: string]: string;
    }>;
    hasLockIcon(itemName: string): Promise<boolean>;
    getLockOwner(itemName: string): Promise<string>;
    hasHighlightedText(location: 'name' | 'description' | 'content'): Promise<boolean>;
}
